//Copyright (C) 2000 Microsoft Corporation.  All rights reserved.

//This source code is intended only as a supplement to Microsoft
//Development Tools and/or on-line documentation.  See these other
//materials for detailed information regarding Microsoft code samples.

//THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY
//KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
//IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
//PARTICULAR PURPOSE.

namespace MdiBaseSimple
{
	using System;
	using System.IO ;
	using System.Drawing;
	using System.Runtime.Serialization;
	using System.Runtime.Serialization.Formatters.Binary ;
	using System.Windows.Forms ;

	/// <summary>
	///    Summary description for Doc.
	/// </summary>
	[SerializableAttribute]
	public class MdiDoc
	{
		// The document keeps track of the current pen width on
		// behalf of all views. We'd like the user interface of
		// Scribble to be such that if the user chooses the Draw
		// Thick Line command, it will apply to all views, not just
		// the view that currently has the focus.

		public bool iMdirty;
		public event UpdateEvent Update;
	
		public MdiDoc(MdiContext context)
		{
			iMdirty= false;		
			m_context = context;
		}



		// Deletes the contents of the document
		public virtual void DeleteContents()
		{
			UpdateAllViews(null);
		}

		public void UpdateAllViews(Object sender) 
		{
			//Update routine can test if sender is same as view.
			if (Update != null) Update(sender);
		}


		public virtual bool Modified 
		{
			get 
			{
				return iMdirty;
			}
			set
			{
				iMdirty = value;
			}
		}

		private MdiContext m_context;
		public MdiContext Context 
		{
			get 
			{
				return m_context;
			}
		}
	}

	public delegate void UpdateEvent(Object sender);
}
